==> jackson-dataformat-xml_2.12.1.orig.tar.xz: jackson-dataformat-xml-jackson-dataformat-xml-2.12.1/src/test/java/com/fasterxml/jackson/dataformat/xml/jaxb/NamespaceViaJAXB18Test.java <==
package com.fasterxml.jackson.dataformat.xml.jaxb;

import com.fasterxml.jackson.databind.type.TypeFactory;
import com.fasterxml.jackson.dataformat.xml.XmlMapper;
import com.fasterxml.jackson.dataformat.xml.XmlTestBase;

import com.fasterxml.jackson.module.jaxb.JaxbAnnotationIntrospector;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

public class NamespaceViaJAXB18Test extends XmlTestBase
{
    final static String TEST_NAMESPACE = "http://namespace-base";

    @XmlRootElement(namespace = TEST_NAMESPACE)
    interface Facility { }

    static class House implements Facility {
        @XmlAttribute
        public String getName() { return "Bob"; }
    }

    @XmlRootElement(namespace = "", name = "Houzz")
    static class HouseWithNoNamespace implements Facility {
        @XmlAttribute
        public String getName() { return "Bill"; }
    }

    // Also: for better or worse, cannot only override local name so:
    @XmlRootElement(name = "Houzz2")
    static class HouseWithNoNamespace2 implements Facility {
        @XmlAttribute
        public String getName() { return "Frank"; }
    }
    
    private final XmlMapper MAPPER = mapperBuilder()
            .annotationIntrospector(new JaxbAnnotationIntrospector(TypeFactory.defaultInstance()))
            .build();

    // [dataformat-xml#18]
    public void testNamespaceViaJAXB() throws Exception
    {
        String xml = MAPPER.writeValueAsString(new House());
        if (!xml.contains("<House xmlns")
                 || !xml.contains(TEST_NAMESPACE)) {
            fail("Expected `xmlns` declaration for element `House`, none seen: XML = "+xml);
        }

        // But should be able to mask it...
        xml = MAPPER.writeValueAsString(new HouseWithNoNamespace());
        if (!xml.contains("<Houzz")
                || xml.contains("xmlns")) {
            fail("Expected NO `xmlns` declaration for element `Houzz` but got XML = "+xml);
        }

        xml = MAPPER.writeValueAsString(new HouseWithNoNamespace2());
        if (!xml.contains("<Houzz2")
                || xml.contains("xmlns")) {
            fail("Expected NO `xmlns` declaration for element `Houzz2` but got XML = "+xml);
        }
    }
}

==> jackson-dataformat-xml_2.14.0.orig.tar.xz: jackson-dataformat-xml-jackson-dataformat-xml-2.14.0/src/test/java/com/fasterxml/jackson/dataformat/xml/jaxb/NamespaceViaJAXB18Test.java <==
package com.fasterxml.jackson.dataformat.xml.jaxb;

import com.fasterxml.jackson.dataformat.xml.XmlMapper;
import com.fasterxml.jackson.dataformat.xml.XmlTestBase;

import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlRootElement;

public class NamespaceViaJAXB18Test extends XmlTestBase
{
    final static String TEST_NAMESPACE = "http://namespace-base";

    @XmlRootElement(namespace = TEST_NAMESPACE)
    interface Facility { }

    static class House implements Facility {
        @XmlAttribute
        public String getName() { return "Bob"; }
    }

    @XmlRootElement(namespace = "", name = "Houzz")
    static class HouseWithNoNamespace implements Facility {
        @XmlAttribute
        public String getName() { return "Bill"; }
    }

    // Also: for better or worse, cannot only override local name so:
    @XmlRootElement(name = "Houzz2")
    static class HouseWithNoNamespace2 implements Facility {
        @XmlAttribute
        public String getName() { return "Frank"; }
    }
    
    private final XmlMapper MAPPER = mapperBuilder()
            .annotationIntrospector(jakartaXMLBindAnnotationIntrospector())
            .build();

    // [dataformat-xml#18]
    public void testNamespaceViaJAXB() throws Exception
    {
        String xml = MAPPER.writeValueAsString(new House());
        if (!xml.contains("<House xmlns")
                 || !xml.contains(TEST_NAMESPACE)) {
            fail("Expected `xmlns` declaration for element `House`, none seen: XML = "+xml);
        }

        // But should be able to mask it...
        xml = MAPPER.writeValueAsString(new HouseWithNoNamespace());
        if (!xml.contains("<Houzz")
                || xml.contains("xmlns")) {
            fail("Expected NO `xmlns` declaration for element `Houzz` but got XML = "+xml);
        }

        xml = MAPPER.writeValueAsString(new HouseWithNoNamespace2());
        if (!xml.contains("<Houzz2")
                || xml.contains("xmlns")) {
            fail("Expected NO `xmlns` declaration for element `Houzz2` but got XML = "+xml);
        }
    }
}
